from fastapi import APIRouter, HTTPException, status
from schemas.contactform import ContactFormCreate
from helpers.contactform_helpers import create_contactform, validate_email
from sqlalchemy.orm import Session
from fastapi import Depends
from core.database import get_db

router = APIRouter()

@router.post("/contact-us", status_code=status.HTTP_201_CREATED)
async def create_contact_form(
    contactform_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    if not contactform_data.name or not contactform_data.email or not contactform_data.message:
        raise HTTPException(status_code=400, detail="All fields are required")

    if not validate_email(contactform_data.email):
        raise HTTPException(status_code=400, detail="Invalid email format")

    new_contactform = create_contactform(db=db, contactform_data=contactform_data)
    return new_contactform